aboutsummaryrefslogtreecommitdiffstats
path: root/test.py
diff options
context:
space:
mode:
authorkongr45gpen <electrovesta@gmail.com>2018-01-06 13:18:18 +0200
committerkongr45gpen <electrovesta@gmail.com>2018-01-06 13:19:18 +0200
commit4ac15ab8421c2c92322e715ffd1550203b212a21 (patch)
tree03fffd2c756411aaeaf188223ca4b946b71cd4d3 /test.py
parente04c3d95dd46a40af04e31a0020aec5f02043da3 (diff)
downloadsupybot_github-4ac15ab8421c2c92322e715ffd1550203b212a21.tar.gz
supybot_github-4ac15ab8421c2c92322e715ffd1550203b212a21.tar.bz2
supybot_github-4ac15ab8421c2c92322e715ffd1550203b212a21.zip
Add configuration value to specify the binding address of the HTTP server
Implements #24
Diffstat (limited to 'test.py')
-rw-r--r--test.py10
1 files changed, 6 insertions, 4 deletions
diff --git a/test.py b/test.py
index 443f548..67aa1f4 100644
--- a/test.py
+++ b/test.py
@@ -7,17 +7,19 @@ from local.testing.ExpectationPluginTestCase import *
class GithubTestCase(ExpectationPluginTestCase):
plugins = ('Github',)
port = 27230
+ address = '127.0.0.1'
files = {}
config = { 'plugins.github.shortUrl': False,
'plugins.github.hidePush': False
}
def setUp(self):
# Set a different port from the default one to make testing while a
# supybot-github instance is running possible - we don't use the config
# variable because supybot's test framework sets the value after the
# plugin has been loaded
conf.supybot.plugins.get("Github").get('port').setValue(self.port)
+ conf.supybot.plugins.get("Github").get('address').setValue(self.address)
PluginTestCase.setUp(self)

© 2014-2024 Faster IT GmbH | imprint | privacy policy
@@ -7,17 +7,19 @@ from local.testing.ExpectationPluginTestCase import *
}
def setUp(self):
- # Set a different port from the default one to make testing while a
- # supybot-github instance is running possible - we don't use the config
- # variable because supybot's test framework sets the value after the
- # plugin has been loaded
+ # Set a different port and address from the default one to make
+ # testing while a supybot-github instance is running possible - we
+ # don't use the config variable because supybot's test framework sets
+ # the value after the plugin has been loaded
conf.supybot.plugins.get("Github").get('port').setValue(self.port)